import { $fetch } from "ofetch";
import SanityClient from "./SanityClient.js";
const API_HOST = "api.sanity.io";
const API_CDN_HOST = "apicdn.sanity.io";
class MinimalSanityClient extends SanityClient {
  queryPath;
  fetchOptions;
  constructor(config) {
    super({
      ...config,
      perspective: config.perspective || "raw",
      useCdn: config.perspective === "previewDrafts" ? false : config.useCdn
    });
    this.queryPath = `/v${config.apiVersion}/data/query/${config.dataset}`;
    this.fetchOptions = {
      headers: {
        ...config.token ? { Authorization: `Bearer ${config.token}` } : {},
        Accept: "application/json",
        ...import.meta.server ? { "accept-encoding": "gzip, deflate" } : {}
      }
    };
    if (import.meta.client) {
      this.fetchOptions.credentials = config.withCredentials ? "include" : "omit";
    }
  }
  getByteLength(query) {
    return encodeURI(query).split(/%..|./).length;
  }
  toQueryString(query, params) {
    const baseQueryStr = `?query=${encodeURIComponent(query)}`;
    return Object.keys(params).reduce((acc, paramName) => {
      return acc + `&${encodeURIComponent(`$${paramName}`)}=${encodeURIComponent(JSON.stringify(params[paramName]))}`;
    }, baseQueryStr);
  }
  async fetch(query, params, _options) {
    const perspectiveQueryString = `&perspective=${_options?.perspective || this.config.perspective}`;
    const queryString = this.toQueryString(query, params || {}) + (this.config.useCdn ? "" : perspectiveQueryString);
    const byteLength = this.getByteLength(queryString);
    const isEligibleForGetRequest = byteLength <= 9e3;
    const minimalClientConfig = typeof this.config.minimalClient === "object" ? this.config.minimalClient : {};
    const useCache = minimalClientConfig.cachingEnabled && isEligibleForGetRequest;
    const requestUrl = useCache && minimalClientConfig.cacheBaseUrl ? minimalClientConfig.cacheBaseUrl + minimalClientConfig.queryEndpoint : `https://${this.config.projectId}.${this.config.useCdn && isEligibleForGetRequest ? API_CDN_HOST : API_HOST}${this.queryPath}`;
    return (await $fetch(requestUrl + queryString, {
      ...this.fetchOptions,
      method: isEligibleForGetRequest ? "GET" : "POST",
      body: !isEligibleForGetRequest ? { query, params } : void 0
    })).result;
  }
  clone() {
    return new MinimalSanityClient({
      useCdn: this.config.useCdn,
      projectId: this.config.projectId,
      dataset: this.config.dataset,
      apiVersion: this.config.apiVersion,
      withCredentials: this.config.withCredentials,
      token: this.config.token,
      perspective: this.config.perspective,
      minimalClient: this.config.minimalClient
    });
  }
}
export default MinimalSanityClient;
